# algorithmia-api-client
APIs for managing actions on the Algorithmia platform

This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 1.5.0
- Package version: 1.5.0
- Build package: org.openapitools.codegen.languages.PythonClientCodegen
For more information, please visit [https://algorithmia.com/contact](https://algorithmia.com/contact)

## Requirements.

Python >= 3.6

## Installation & Usage
### pip install

If the python package is hosted on a repository, you can install directly using:

```sh
pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git
```
(you may need to run `pip` with root permission: `sudo pip install git+https://github.com/GIT_USER_ID/GIT_REPO_ID.git`)

Then import the package:
```python
import algorithmia_api_client
```

### Setuptools

Install via [Setuptools](http://pypi.python.org/pypi/setuptools).

```sh
python setup.py install --user
```
(or `sudo python setup.py install` to install the package for all users)

Then import the package:
```python
import algorithmia_api_client
```

## Getting Started

Please follow the [installation procedure](#installation--usage) and then run the following:

```python

import time
import algorithmia_api_client
from pprint import pprint
from algorithmia_api_client.api import admin_api
from algorithmia_api_client.model.algorithm_usage_result import AlgorithmUsageResult
from algorithmia_api_client.model.api_key import ApiKey
from algorithmia_api_client.model.create_organization_host_information import CreateOrganizationHostInformation
from algorithmia_api_client.model.feature_flag_list import FeatureFlagList
from algorithmia_api_client.model.feature_flag_toggle import FeatureFlagToggle
from algorithmia_api_client.model.full_usage_result import FullUsageResult
from algorithmia_api_client.model.inline_response500 import InlineResponse500
from algorithmia_api_client.model.organization_host_information import OrganizationHostInformation
from algorithmia_api_client.model.provider_info import ProviderInfo
from algorithmia_api_client.model.reservation import Reservation
from algorithmia_api_client.model.reservation_create import ReservationCreate
from algorithmia_api_client.model.scm_configuration_request_dto import ScmConfigurationRequestDto
from algorithmia_api_client.model.scm_configuration_response_dto import ScmConfigurationResponseDto
from algorithmia_api_client.model.scm_update_request import ScmUpdateRequest
from algorithmia_api_client.model.secret_provider_request import SecretProviderRequest
from algorithmia_api_client.model.user_usage_result import UserUsageResult
# Defining the host is optional and defaults to https://api.algorithmia.com
# See configuration.py for a list of all supported configuration parameters.
configuration = algorithmia_api_client.Configuration(
    host = "https://api.algorithmia.com"
)



# Enter a context with an instance of the API client
with algorithmia_api_client.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = admin_api.AdminApi(api_client)
    
    try:
        # List secret providers as an admin user
        api_response = api_instance.admin_list_secret_providers()
        pprint(api_response)
    except algorithmia_api_client.ApiException as e:
        print("Exception when calling AdminApi->admin_list_secret_providers: %s\n" % e)
```

## Documentation for API Endpoints

All URIs are relative to *https://api.algorithmia.com*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*AdminApi* | [**admin_list_secret_providers**](docs/AdminApi.md#admin_list_secret_providers) | **GET** /v1/admin/secret-provider | List secret providers as an admin user
*AdminApi* | [**check_secret_provider_for_jar**](docs/AdminApi.md#check_secret_provider_for_jar) | **GET** /v1/admin/plugins/secret-provider/{providerId} | Check if a .jar file has been uploaded for a secret provider
*AdminApi* | [**create_organization_host_information**](docs/AdminApi.md#create_organization_host_information) | **POST** /v1/admin/organization_host_information/{orgName} | Create new Organization Host Information
*AdminApi* | [**create_reservation**](docs/AdminApi.md#create_reservation) | **POST** /v1/admin/reservations | Create a new reservation
*AdminApi* | [**create_scm**](docs/AdminApi.md#create_scm) | **POST** /v1/admin/scms | Create an SCM
*AdminApi* | [**create_secret_provider**](docs/AdminApi.md#create_secret_provider) | **POST** /v1/admin/secret-provider | Create a new secret provider
*AdminApi* | [**delete**](docs/AdminApi.md#delete) | **DELETE** /v1/admin/organization_host_information/{orgName} | Deletes the Organization Host Information for org named
*AdminApi* | [**delete_provider**](docs/AdminApi.md#delete_provider) | **DELETE** /v1/admin/secret-provider/{providerId} | Delete a secret provider by its ID
*AdminApi* | [**delete_reservation**](docs/AdminApi.md#delete_reservation) | **DELETE** /v1/admin/reservations/{reservation_id} | Delete a reservation by id
*AdminApi* | [**delete_scm**](docs/AdminApi.md#delete_scm) | **DELETE** /v1/admin/scms/{scmId} | Delete an SCM
*AdminApi* | [**feature_flag_list**](docs/AdminApi.md#feature_flag_list) | **GET** /v1/admin/features | Lists all available feature flags returned for authorized users
*AdminApi* | [**get_algorithm_usage_result**](docs/AdminApi.md#get_algorithm_usage_result) | **GET** /v1/admin/usage/algorithms | Get algorithm usage information
*AdminApi* | [**get_by_org_name**](docs/AdminApi.md#get_by_org_name) | **GET** /v1/admin/organization_host_information/{orgName} | Get Organization Host Information
*AdminApi* | [**get_full_usage**](docs/AdminApi.md#get_full_usage) | **GET** /v1/admin/usage | Get usage information
*AdminApi* | [**get_reservations**](docs/AdminApi.md#get_reservations) | **GET** /v1/admin/reservations | Get current reservations
*AdminApi* | [**get_secret_provider**](docs/AdminApi.md#get_secret_provider) | **GET** /v1/admin/secret-provider/{providerId} | Get a secret provider by its ID
*AdminApi* | [**get_user_usage_result**](docs/AdminApi.md#get_user_usage_result) | **GET** /v1/admin/usage/users | Get usage information grouped by user
*AdminApi* | [**import_api_key**](docs/AdminApi.md#import_api_key) | **POST** /v1/admin/users/{username}/keys | Add a specific API key for a user
*AdminApi* | [**set_default_scm**](docs/AdminApi.md#set_default_scm) | **POST** /v1/admin/scms/{scmId}/default | Set Default SCM
*AdminApi* | [**set_default_secret_provider**](docs/AdminApi.md#set_default_secret_provider) | **POST** /v1/admin/plugins/secret-provider/{providerId}/default | Make a secret provider the default secret provider
*AdminApi* | [**toggle_feature_flag**](docs/AdminApi.md#toggle_feature_flag) | **PUT** /v1/admin/features/{featureName} | Enabled/disabled a feature flag globally
*AdminApi* | [**update**](docs/AdminApi.md#update) | **PUT** /v1/admin/organization_host_information | Update existing Organization Host Information
*AdminApi* | [**update_provider**](docs/AdminApi.md#update_provider) | **POST** /v1/admin/secret-provider/{providerId} | Update a secret provider by its ID
*AdminApi* | [**update_scm**](docs/AdminApi.md#update_scm) | **PATCH** /v1/admin/scms/{scmId} | Update an SCM
*AdminApi* | [**upload_jar_for_secret_provider**](docs/AdminApi.md#upload_jar_for_secret_provider) | **POST** /v1/admin/plugins/secret-provider/{providerId} | Upload a .jar file for the target secret provider
*AlgorithmsApi* | [**call_algorithm**](docs/AlgorithmsApi.md#call_algorithm) | **POST** /v1/algo/{username}/{algoname}/{algoCallableVersion} | Make a request to an algorithm
*AlgorithmsApi* | [**call_algorithm_by_id**](docs/AlgorithmsApi.md#call_algorithm_by_id) | **POST** /v1/algo/{algorithmId}/{algoCallableVersion} | Make a request to an algorithm by immutable identifier
*AlgorithmsApi* | [**commit_log_for_repository**](docs/AlgorithmsApi.md#commit_log_for_repository) | **GET** /v1/algorithms/{username}/{algoname}/log | List commits for a repository
*AlgorithmsApi* | [**compile_algorithm**](docs/AlgorithmsApi.md#compile_algorithm) | **POST** /v1/algorithms/{username}/{algoname}/compile | Compile algorithm
*AlgorithmsApi* | [**compile_algorithm_by_id**](docs/AlgorithmsApi.md#compile_algorithm_by_id) | **POST** /v1/algorithms/{algorithmId}/compile | Compile algorithm
*AlgorithmsApi* | [**create_algorithm**](docs/AlgorithmsApi.md#create_algorithm) | **POST** /v1/algorithms/{username} | Create algorithm
*AlgorithmsApi* | [**create_algorithm_secret**](docs/AlgorithmsApi.md#create_algorithm_secret) | **POST** /v1/algorithms/{algorithmId}/secrets | Create a secret for the given algorithm
*AlgorithmsApi* | [**delete_algorithm**](docs/AlgorithmsApi.md#delete_algorithm) | **DELETE** /v1/algorithms/{username}/{algoname} | Delete algorithm
*AlgorithmsApi* | [**delete_algorithm_secret**](docs/AlgorithmsApi.md#delete_algorithm_secret) | **DELETE** /v1/algorithms/{algorithmId}/secrets/{secretId} | Delete a secret for the given algorithm
*AlgorithmsApi* | [**edit_algorithm_secret**](docs/AlgorithmsApi.md#edit_algorithm_secret) | **PUT** /v1/algorithms/{algorithmId}/secrets/{secretId} | Edit a secret for the given algorithm
*AlgorithmsApi* | [**get_algorithm**](docs/AlgorithmsApi.md#get_algorithm) | **GET** /v1/algorithms/{username}/{algoname} | Get algorithm metadata
*AlgorithmsApi* | [**get_algorithm_build_by_id**](docs/AlgorithmsApi.md#get_algorithm_build_by_id) | **GET** /v1/algorithms/{username}/{algoname}/builds/{buildid} | Get individual algorithm build by ID
*AlgorithmsApi* | [**get_algorithm_build_logs**](docs/AlgorithmsApi.md#get_algorithm_build_logs) | **GET** /v1/algorithms/{username}/{algoname}/builds/{buildid}/logs | Get algorithm build logs
*AlgorithmsApi* | [**get_algorithm_builds**](docs/AlgorithmsApi.md#get_algorithm_builds) | **GET** /v1/algorithms/{username}/{algoname}/builds | Get algorithm builds
*AlgorithmsApi* | [**get_algorithm_by_id**](docs/AlgorithmsApi.md#get_algorithm_by_id) | **GET** /v1/algorithms/{username} | Get algorithm
*AlgorithmsApi* | [**get_algorithm_by_id_build_by_id**](docs/AlgorithmsApi.md#get_algorithm_by_id_build_by_id) | **GET** /v1/algorithms/{algorithmId}/builds/{buildid} | Get individual algorithm build by ID
*AlgorithmsApi* | [**get_algorithm_by_id_build_logs**](docs/AlgorithmsApi.md#get_algorithm_by_id_build_logs) | **GET** /v1/algorithms/{algorithmId}/builds/{buildid}/logs | Get algorithm build logs
*AlgorithmsApi* | [**get_algorithm_by_id_builds**](docs/AlgorithmsApi.md#get_algorithm_by_id_builds) | **GET** /v1/algorithms/{algorithmId}/builds | Get algorithm builds
*AlgorithmsApi* | [**get_algorithm_errors_by_algorithm_id**](docs/AlgorithmsApi.md#get_algorithm_errors_by_algorithm_id) | **GET** /v1/algorithms/{algorithmId}/errors | Get algorithm errors
*AlgorithmsApi* | [**get_algorithm_errors_by_algorithm_name**](docs/AlgorithmsApi.md#get_algorithm_errors_by_algorithm_name) | **GET** /v1/algorithms/{username}/{algoname}/errors | Get algorithm errors
*AlgorithmsApi* | [**get_algorithm_errors_by_user_id**](docs/AlgorithmsApi.md#get_algorithm_errors_by_user_id) | **GET** /v1/users/{userId}/errors | Get algorithm errors for a given user
*AlgorithmsApi* | [**get_algorithm_hash_version**](docs/AlgorithmsApi.md#get_algorithm_hash_version) | **GET** /v1/algorithms/{username}/{algoname}/versions/{algohash} | Get Algorithm by Hash Version
*AlgorithmsApi* | [**get_algorithm_scm_connection_status**](docs/AlgorithmsApi.md#get_algorithm_scm_connection_status) | **GET** /v1/algorithms/{username}/{algoname}/scm/status | Get algorithm SCM connection status
*AlgorithmsApi* | [**get_algorithm_secrets**](docs/AlgorithmsApi.md#get_algorithm_secrets) | **GET** /v1/algorithms/{algorithmId}/secrets | Get all secrets for an Algorithm
*AlgorithmsApi* | [**get_algorithm_versions**](docs/AlgorithmsApi.md#get_algorithm_versions) | **GET** /v1/algorithms/{username}/{algoname}/versions | Get algorithm versions
*AlgorithmsApi* | [**get_utility_algorithms**](docs/AlgorithmsApi.md#get_utility_algorithms) | **GET** /v1/organizations/{orgName}/utility-algorithms | List of utility algorithms
*AlgorithmsApi* | [**list_algorithms_for_user**](docs/AlgorithmsApi.md#list_algorithms_for_user) | **GET** /v1/users/{username}/algorithms | List algorithms for a user or organization
*AlgorithmsApi* | [**publish_algorithm**](docs/AlgorithmsApi.md#publish_algorithm) | **POST** /v1/algorithms/{username}/{algoname}/versions | Publish an algorithm&#39;s last successful build
*AlgorithmsApi* | [**publish_algorithm_by_id**](docs/AlgorithmsApi.md#publish_algorithm_by_id) | **POST** /v1/algorithms/{algorithmId}/versions | Publish an algorithm&#39;s last successful build
*AlgorithmsApi* | [**receive_algorithm_by_id_scm_repository_event**](docs/AlgorithmsApi.md#receive_algorithm_by_id_scm_repository_event) | **POST** /v1/algorithms/{algorithmId}/scm/webhook | Receiver of all SCM repository events
*AlgorithmsApi* | [**receive_scm_repository_event**](docs/AlgorithmsApi.md#receive_scm_repository_event) | **POST** /v1/algorithms/{username}/{algoname}/scm/webhook | Receiver of all SCM repository events
*AlgorithmsApi* | [**update_algorithm**](docs/AlgorithmsApi.md#update_algorithm) | **PUT** /v1/algorithms/{username}/{algoname} | Update algorithm settings
*AlgorithmsApi* | [**update_algorithm_by_id**](docs/AlgorithmsApi.md#update_algorithm_by_id) | **PUT** /v1/algorithms/{username} | Update algorithm
*AuthApi* | [**create_key_for_user**](docs/AuthApi.md#create_key_for_user) | **POST** /v1/users/{username}/keys | Create an API key for a given user
*AuthApi* | [**get_keys_for_user**](docs/AuthApi.md#get_keys_for_user) | **GET** /v1/users/{username}/keys | Get all API keys for a user
*BuildsApi* | [**commit_log_for_repository**](docs/BuildsApi.md#commit_log_for_repository) | **GET** /v1/algorithms/{username}/{algoname}/log | List commits for a repository
*BuildsApi* | [**compile_algorithm**](docs/BuildsApi.md#compile_algorithm) | **POST** /v1/algorithms/{username}/{algoname}/compile | Compile algorithm
*BuildsApi* | [**compile_algorithm_by_id**](docs/BuildsApi.md#compile_algorithm_by_id) | **POST** /v1/algorithms/{algorithmId}/compile | Compile algorithm
*BuildsApi* | [**get_algorithm_build_by_id**](docs/BuildsApi.md#get_algorithm_build_by_id) | **GET** /v1/algorithms/{username}/{algoname}/builds/{buildid} | Get individual algorithm build by ID
*BuildsApi* | [**get_algorithm_build_logs**](docs/BuildsApi.md#get_algorithm_build_logs) | **GET** /v1/algorithms/{username}/{algoname}/builds/{buildid}/logs | Get algorithm build logs
*BuildsApi* | [**get_algorithm_builds**](docs/BuildsApi.md#get_algorithm_builds) | **GET** /v1/algorithms/{username}/{algoname}/builds | Get algorithm builds
*BuildsApi* | [**get_algorithm_by_id_build_by_id**](docs/BuildsApi.md#get_algorithm_by_id_build_by_id) | **GET** /v1/algorithms/{algorithmId}/builds/{buildid} | Get individual algorithm build by ID
*BuildsApi* | [**get_algorithm_by_id_build_logs**](docs/BuildsApi.md#get_algorithm_by_id_build_logs) | **GET** /v1/algorithms/{algorithmId}/builds/{buildid}/logs | Get algorithm build logs
*BuildsApi* | [**get_algorithm_by_id_builds**](docs/BuildsApi.md#get_algorithm_by_id_builds) | **GET** /v1/algorithms/{algorithmId}/builds | Get algorithm builds
*BuildsApi* | [**get_algorithm_scm_connection_status**](docs/BuildsApi.md#get_algorithm_scm_connection_status) | **GET** /v1/algorithms/{username}/{algoname}/scm/status | Get algorithm SCM connection status
*ConnectionsApi* | [**delete_all_connections**](docs/ConnectionsApi.md#delete_all_connections) | **DELETE** /v1/admin/insights-connection | deletes all the configured connections
*ConnectionsApi* | [**get_connection**](docs/ConnectionsApi.md#get_connection) | **GET** /v1/admin/insights-connection | Gets the currently configured connection
*ConnectionsApi* | [**update_connection**](docs/ConnectionsApi.md#update_connection) | **POST** /v1/admin/insights-connection | Sets the connection configuration
*ConnectorsApi* | [**create_connector_for_user_by_id**](docs/ConnectorsApi.md#create_connector_for_user_by_id) | **POST** /v1/users/{username}/connectors | Create connector for a user
*ConnectorsApi* | [**create_directory**](docs/ConnectorsApi.md#create_directory) | **POST** /v1/connector/{connectorId}/{connectorPath} | Create new directory
*ConnectorsApi* | [**delete_file_or_directory**](docs/ConnectorsApi.md#delete_file_or_directory) | **DELETE** /v1/connector/{connectorId}/{connectorPath} | Delete file or directory
*ConnectorsApi* | [**get_file_or_directory**](docs/ConnectorsApi.md#get_file_or_directory) | **GET** /v1/connector/{connectorId}/{connectorPath} | Get file contents or directory listing
*ConnectorsApi* | [**update_directory_acl**](docs/ConnectorsApi.md#update_directory_acl) | **PATCH** /v1/connector/{connectorId}/{connectorPath} | Update directory
*ConnectorsApi* | [**upload_file**](docs/ConnectorsApi.md#upload_file) | **PUT** /v1/connector/{connectorId}/{connectorPath} | Upload file
*ConnectorsApi* | [**verify_file_existence**](docs/ConnectorsApi.md#verify_file_existence) | **HEAD** /v1/connector/{connectorId}/{connectorPath} | Check if file exists
*DataApi* | [**create_directory**](docs/DataApi.md#create_directory) | **POST** /v1/connector/{connectorId}/{connectorPath} | Create new directory
*DataApi* | [**delete_file_or_directory**](docs/DataApi.md#delete_file_or_directory) | **DELETE** /v1/connector/{connectorId}/{connectorPath} | Delete file or directory
*DataApi* | [**get_file_or_directory**](docs/DataApi.md#get_file_or_directory) | **GET** /v1/connector/{connectorId}/{connectorPath} | Get file contents or directory listing
*DataApi* | [**update_directory_acl**](docs/DataApi.md#update_directory_acl) | **PATCH** /v1/connector/{connectorId}/{connectorPath} | Update directory
*DataApi* | [**upload_file**](docs/DataApi.md#upload_file) | **PUT** /v1/connector/{connectorId}/{connectorPath} | Upload file
*DataApi* | [**verify_file_existence**](docs/DataApi.md#verify_file_existence) | **HEAD** /v1/connector/{connectorId}/{connectorPath} | Check if file exists
*EventlistenersApi* | [**delete_event_listener_for_user_by_id**](docs/EventlistenersApi.md#delete_event_listener_for_user_by_id) | **DELETE** /v1/users/{userId}/event-listeners/{eventListenerId} | Delete an event listener
*EventlistenersApi* | [**get_event_listener_by_id_for_user_by_id**](docs/EventlistenersApi.md#get_event_listener_by_id_for_user_by_id) | **GET** /v1/users/{userId}/event-listeners/{eventListenerId} | Get the event listener with provided ID configured for the provided user ID
*EventlistenersApi* | [**get_event_listeners_for_user_by_id**](docs/EventlistenersApi.md#get_event_listeners_for_user_by_id) | **GET** /v1/users/{userId}/event-listeners | Get the event listeners configured for the provided user ID
*EventlistenersApi* | [**post_event_listeners_for_user_by_id**](docs/EventlistenersApi.md#post_event_listeners_for_user_by_id) | **POST** /v1/users/{userId}/event-listeners | Creates a new event listener for a user by ID
*EventlistenersApi* | [**update_event_listener_for_user_by_id**](docs/EventlistenersApi.md#update_event_listener_for_user_by_id) | **PUT** /v1/users/{userId}/event-listeners/{eventListenerId} | Update an event listener with provided ID configured for the provided user ID
*FrontendApi* | [**delete_config_entry**](docs/FrontendApi.md#delete_config_entry) | **DELETE** /v1/config/frontend/{keyname} | Delete a config entry represented by the provided keyname
*FrontendApi* | [**get_config_entry**](docs/FrontendApi.md#get_config_entry) | **GET** /v1/config/frontend/{keyname} | Get a frontend config entry represeted by the provided keyname
*FrontendApi* | [**get_frontend_config_entries**](docs/FrontendApi.md#get_frontend_config_entries) | **GET** /v1/config/frontend | List all frontend configuration values
*FrontendApi* | [**update_config_entry**](docs/FrontendApi.md#update_config_entry) | **PUT** /v1/config/frontend/{keyname} | Update or insert a config entry represented by the provided keyname
*InvitesApi* | [**add_invite**](docs/InvitesApi.md#add_invite) | **POST** /v1/admin/invites | Add an invite code
*InvitesApi* | [**delete_invite**](docs/InvitesApi.md#delete_invite) | **DELETE** /v1/admin/invites/{invite_code} | Delete an invite code
*InvitesApi* | [**get_invites**](docs/InvitesApi.md#get_invites) | **GET** /v1/admin/invites | Get a list of invite codes
*OrganizationsApi* | [**add_organization_api_key**](docs/OrganizationsApi.md#add_organization_api_key) | **POST** /v1/organizations/{orgName}/members/{username}/keys | Create an organization API key for a user
*OrganizationsApi* | [**add_organization_member**](docs/OrganizationsApi.md#add_organization_member) | **PUT** /v1/organizations/{orgName}/members/{username} | Add a user as a member of a given organization
*OrganizationsApi* | [**create**](docs/OrganizationsApi.md#create) | **POST** /v1/organization/types | Create an OrganizationType
*OrganizationsApi* | [**create_key_for_organization**](docs/OrganizationsApi.md#create_key_for_organization) | **POST** /v1/organizations/{orgName}/keys | Create an AlgorithmKey for an organization
*OrganizationsApi* | [**create_organization**](docs/OrganizationsApi.md#create_organization) | **POST** /v1/organizations | Creates an organization owned by the caller
*OrganizationsApi* | [**create_organization_host_information**](docs/OrganizationsApi.md#create_organization_host_information) | **POST** /v1/admin/organization_host_information/{orgName} | Create new Organization Host Information
*OrganizationsApi* | [**delete**](docs/OrganizationsApi.md#delete) | **DELETE** /v1/admin/organization_host_information/{orgName} | Deletes the Organization Host Information for org named
*OrganizationsApi* | [**delete_by_name**](docs/OrganizationsApi.md#delete_by_name) | **DELETE** /v1/organization/types/{orgTypeName} | Remove an organization type by name
*OrganizationsApi* | [**delete_host_usernames**](docs/OrganizationsApi.md#delete_host_usernames) | **DELETE** /v1/organizations/{orgName}/algorithms-host-usernames/{algorithmId} | Deletes functional-ids associated with a given algorithm
*OrganizationsApi* | [**delete_organization**](docs/OrganizationsApi.md#delete_organization) | **DELETE** /v1/organizations/{orgName} | Delete an organization
*OrganizationsApi* | [**edit**](docs/OrganizationsApi.md#edit) | **PUT** /v1/organizations/{orgName} | Update an organization
*OrganizationsApi* | [**get_all_organization_types**](docs/OrganizationsApi.md#get_all_organization_types) | **GET** /v1/organization/types | Get all organization types
*OrganizationsApi* | [**get_by_org_name**](docs/OrganizationsApi.md#get_by_org_name) | **GET** /v1/admin/organization_host_information/{orgName} | Get Organization Host Information
*OrganizationsApi* | [**get_host_usernames**](docs/OrganizationsApi.md#get_host_usernames) | **GET** /v1/organizations/{orgName}/algorithms-host-usernames | List of all the AlgorithmHostUsername \&quot;algorithm-id / functional-id\&quot; pairs
*OrganizationsApi* | [**get_organization**](docs/OrganizationsApi.md#get_organization) | **GET** /v1/organizations/{orgName} | Get an organization represented by the provided orgName
*OrganizationsApi* | [**get_organizations**](docs/OrganizationsApi.md#get_organizations) | **GET** /v1/organizations | Lists all organizations
*OrganizationsApi* | [**get_utility_algorithms**](docs/OrganizationsApi.md#get_utility_algorithms) | **GET** /v1/organizations/{orgName}/utility-algorithms | List of utility algorithms
*OrganizationsApi* | [**list_keys**](docs/OrganizationsApi.md#list_keys) | **GET** /v1/organizations/{orgName}/keys | List all the keys in an organization
*OrganizationsApi* | [**list_members**](docs/OrganizationsApi.md#list_members) | **GET** /v1/organizations/{orgName}/members | List of members with their roles in a given organization
*OrganizationsApi* | [**remove_organization_member**](docs/OrganizationsApi.md#remove_organization_member) | **DELETE** /v1/organizations/{orgName}/members/{username} | Remove a user from an organization
*OrganizationsApi* | [**set_host_usernames**](docs/OrganizationsApi.md#set_host_usernames) | **PUT** /v1/organizations/{orgName}/algorithms-host-usernames | Adds a list of algorithm-id / functional-id pairs
*OrganizationsApi* | [**update**](docs/OrganizationsApi.md#update) | **PUT** /v1/admin/organization_host_information | Update existing Organization Host Information
*ReservationsApi* | [**create_reservation**](docs/ReservationsApi.md#create_reservation) | **POST** /v1/admin/reservations | Create a new reservation
*ReservationsApi* | [**delete_reservation**](docs/ReservationsApi.md#delete_reservation) | **DELETE** /v1/admin/reservations/{reservation_id} | Delete a reservation by id
*ReservationsApi* | [**get_reservations**](docs/ReservationsApi.md#get_reservations) | **GET** /v1/admin/reservations | Get current reservations
*ScmApi* | [**add_scm_connection**](docs/ScmApi.md#add_scm_connection) | **POST** /v1/scms/{scmId}/token/connect | Create SCM authorized connection
*ScmApi* | [**complete_scm_authorization**](docs/ScmApi.md#complete_scm_authorization) | **GET** /v1/scms/{scmId}/oauth/finish | Complete SCM authorization
*ScmApi* | [**create_scm**](docs/ScmApi.md#create_scm) | **POST** /v1/admin/scms | Create an SCM
*ScmApi* | [**delete_scm**](docs/ScmApi.md#delete_scm) | **DELETE** /v1/admin/scms/{scmId} | Delete an SCM
*ScmApi* | [**get_algorithm_scm_connection_status**](docs/ScmApi.md#get_algorithm_scm_connection_status) | **GET** /v1/algorithms/{username}/{algoname}/scm/status | Get algorithm SCM connection status
*ScmApi* | [**get_scm**](docs/ScmApi.md#get_scm) | **GET** /v1/scms/{scmId} | Get SCM information
*ScmApi* | [**get_scm_status**](docs/ScmApi.md#get_scm_status) | **GET** /v1/scms/{scmId}/oauth/status | Get SCM authorization status
*ScmApi* | [**initiate_scm_authorization**](docs/ScmApi.md#initiate_scm_authorization) | **GET** /v1/scms/{scmId}/oauth/start | Initiate SCM authorization
*ScmApi* | [**list_scms**](docs/ScmApi.md#list_scms) | **GET** /v1/scms | List SCMs
*ScmApi* | [**receive_algorithm_by_id_scm_repository_event**](docs/ScmApi.md#receive_algorithm_by_id_scm_repository_event) | **POST** /v1/algorithms/{algorithmId}/scm/webhook | Receiver of all SCM repository events
*ScmApi* | [**receive_scm_repository_event**](docs/ScmApi.md#receive_scm_repository_event) | **POST** /v1/algorithms/{username}/{algoname}/scm/webhook | Receiver of all SCM repository events
*ScmApi* | [**revoke_scm_authorization**](docs/ScmApi.md#revoke_scm_authorization) | **POST** /v1/scms/{scmId}/oauth/revoke | Revoke SCM Authorization
*ScmApi* | [**scm_token_status**](docs/ScmApi.md#scm_token_status) | **GET** /v1/scms/{scmId}/token/status | Get SCM authorization status
*ScmApi* | [**set_default_scm**](docs/ScmApi.md#set_default_scm) | **POST** /v1/admin/scms/{scmId}/default | Set Default SCM
*ScmApi* | [**update_scm**](docs/ScmApi.md#update_scm) | **PATCH** /v1/admin/scms/{scmId} | Update an SCM
*SecretsApi* | [**admin_list_secret_providers**](docs/SecretsApi.md#admin_list_secret_providers) | **GET** /v1/admin/secret-provider | List secret providers as an admin user
*SecretsApi* | [**check_secret_provider_for_jar**](docs/SecretsApi.md#check_secret_provider_for_jar) | **GET** /v1/admin/plugins/secret-provider/{providerId} | Check if a .jar file has been uploaded for a secret provider
*SecretsApi* | [**create_algorithm_secret**](docs/SecretsApi.md#create_algorithm_secret) | **POST** /v1/algorithms/{algorithmId}/secrets | Create a secret for the given algorithm
*SecretsApi* | [**create_secret_provider**](docs/SecretsApi.md#create_secret_provider) | **POST** /v1/admin/secret-provider | Create a new secret provider
*SecretsApi* | [**delete_algorithm_secret**](docs/SecretsApi.md#delete_algorithm_secret) | **DELETE** /v1/algorithms/{algorithmId}/secrets/{secretId} | Delete a secret for the given algorithm
*SecretsApi* | [**delete_provider**](docs/SecretsApi.md#delete_provider) | **DELETE** /v1/admin/secret-provider/{providerId} | Delete a secret provider by its ID
*SecretsApi* | [**edit_algorithm_secret**](docs/SecretsApi.md#edit_algorithm_secret) | **PUT** /v1/algorithms/{algorithmId}/secrets/{secretId} | Edit a secret for the given algorithm
*SecretsApi* | [**get_algorithm_secrets**](docs/SecretsApi.md#get_algorithm_secrets) | **GET** /v1/algorithms/{algorithmId}/secrets | Get all secrets for an Algorithm
*SecretsApi* | [**get_secret_provider**](docs/SecretsApi.md#get_secret_provider) | **GET** /v1/admin/secret-provider/{providerId} | Get a secret provider by its ID
*SecretsApi* | [**list_secret_providers**](docs/SecretsApi.md#list_secret_providers) | **GET** /v1/secret-provider | List all secret providers
*SecretsApi* | [**set_default_secret_provider**](docs/SecretsApi.md#set_default_secret_provider) | **POST** /v1/admin/plugins/secret-provider/{providerId}/default | Make a secret provider the default secret provider
*SecretsApi* | [**update_provider**](docs/SecretsApi.md#update_provider) | **POST** /v1/admin/secret-provider/{providerId} | Update a secret provider by its ID
*SecretsApi* | [**upload_jar_for_secret_provider**](docs/SecretsApi.md#upload_jar_for_secret_provider) | **POST** /v1/admin/plugins/secret-provider/{providerId} | Upload a .jar file for the target secret provider
*StyleApi* | [**delete_favicon**](docs/StyleApi.md#delete_favicon) | **DELETE** /v1/config/favicon | Delete favicon for the Algorithmia instance
*StyleApi* | [**delete_logo**](docs/StyleApi.md#delete_logo) | **DELETE** /v1/config/logo | Delete logo for the Algorithmia instance
*StyleApi* | [**get_favicon**](docs/StyleApi.md#get_favicon) | **GET** /v1/config/favicon | Get favicon for the Algorithmia instance
*StyleApi* | [**get_logo**](docs/StyleApi.md#get_logo) | **GET** /v1/config/logo | Get logo for the Algorithmia instance
*StyleApi* | [**update_favicon**](docs/StyleApi.md#update_favicon) | **POST** /v1/config/favicon | Update favicon for the Algorithmia instance
*StyleApi* | [**update_logo**](docs/StyleApi.md#update_logo) | **POST** /v1/config/logo | Update logo for the Algorithmia instance
*UsageApi* | [**get_algorithm_usage_result**](docs/UsageApi.md#get_algorithm_usage_result) | **GET** /v1/admin/usage/algorithms | Get algorithm usage information
*UsageApi* | [**get_full_usage**](docs/UsageApi.md#get_full_usage) | **GET** /v1/admin/usage | Get usage information
*UsageApi* | [**get_user_usage_result**](docs/UsageApi.md#get_user_usage_result) | **GET** /v1/admin/usage/users | Get usage information grouped by user
*UsersApi* | [**create_user**](docs/UsersApi.md#create_user) | **POST** /v1/users | Creates an Algorithmia user in the system
*UsersApi* | [**delete_user**](docs/UsersApi.md#delete_user) | **DELETE** /v1/users/{username} | Delete a user represented by the provided user id
*UsersApi* | [**get_user**](docs/UsersApi.md#get_user) | **GET** /v1/users/{username} | Get a user represented by the provided user id
*UsersApi* | [**get_users**](docs/UsersApi.md#get_users) | **GET** /v1/users | Lists all managed users
*UsersApi* | [**update_user**](docs/UsersApi.md#update_user) | **PUT** /v1/users/{username} | Update a user represented by the provided user id


## Documentation For Models

 - [AlgorithmAsynchronousInvocationResult](docs/AlgorithmAsynchronousInvocationResult.md)
 - [AlgorithmCallability](docs/AlgorithmCallability.md)
 - [AlgorithmErrorEntry](docs/AlgorithmErrorEntry.md)
 - [AlgorithmHostUsername](docs/AlgorithmHostUsername.md)
 - [AlgorithmHostUsernameUpdates](docs/AlgorithmHostUsernameUpdates.md)
 - [AlgorithmInvocationResult](docs/AlgorithmInvocationResult.md)
 - [AlgorithmListResult](docs/AlgorithmListResult.md)
 - [AlgorithmSecretCreateRequest](docs/AlgorithmSecretCreateRequest.md)
 - [AlgorithmSecretEditRequest](docs/AlgorithmSecretEditRequest.md)
 - [AlgorithmSecretList](docs/AlgorithmSecretList.md)
 - [AlgorithmSecretResult](docs/AlgorithmSecretResult.md)
 - [AlgorithmSynchronousInvocationResult](docs/AlgorithmSynchronousInvocationResult.md)
 - [AlgorithmSynchronousInvocationResultError](docs/AlgorithmSynchronousInvocationResultError.md)
 - [AlgorithmSynchronousInvocationResultMetadata](docs/AlgorithmSynchronousInvocationResultMetadata.md)
 - [AlgorithmSynchronousInvocationResultOneOf](docs/AlgorithmSynchronousInvocationResultOneOf.md)
 - [AlgorithmUsageResult](docs/AlgorithmUsageResult.md)
 - [AlgorithmUsageRow](docs/AlgorithmUsageRow.md)
 - [ApiKey](docs/ApiKey.md)
 - [ApiKeyCreation](docs/ApiKeyCreation.md)
 - [ApiKeyList](docs/ApiKeyList.md)
 - [ApiKeyType](docs/ApiKeyType.md)
 - [AuthPermissions](docs/AuthPermissions.md)
 - [Build](docs/Build.md)
 - [BuildLogs](docs/BuildLogs.md)
 - [BuildRequest](docs/BuildRequest.md)
 - [BuildVersionInfo](docs/BuildVersionInfo.md)
 - [Commit](docs/Commit.md)
 - [Compilation](docs/Compilation.md)
 - [ConnectionConfiguration](docs/ConnectionConfiguration.md)
 - [ConnectionConfigurationRequest](docs/ConnectionConfigurationRequest.md)
 - [Connector](docs/Connector.md)
 - [ConnectorResponse](docs/ConnectorResponse.md)
 - [CreateDirectoryRequest](docs/CreateDirectoryRequest.md)
 - [CreateOrganizationHostInformation](docs/CreateOrganizationHostInformation.md)
 - [CreateRequest](docs/CreateRequest.md)
 - [CreateRequestVersionInfo](docs/CreateRequestVersionInfo.md)
 - [Details](docs/Details.md)
 - [Directory](docs/Directory.md)
 - [DirectoryAcl](docs/DirectoryAcl.md)
 - [DirectoryAclUpdateRequest](docs/DirectoryAclUpdateRequest.md)
 - [Environment](docs/Environment.md)
 - [Error](docs/Error.md)
 - [EventListener](docs/EventListener.md)
 - [EventListenerRequest](docs/EventListenerRequest.md)
 - [EventListenerSourceType](docs/EventListenerSourceType.md)
 - [FeatureFlag](docs/FeatureFlag.md)
 - [FeatureFlagList](docs/FeatureFlagList.md)
 - [FeatureFlagToggle](docs/FeatureFlagToggle.md)
 - [File](docs/File.md)
 - [FileType](docs/FileType.md)
 - [Folder](docs/Folder.md)
 - [FrontendConfigurationEntry](docs/FrontendConfigurationEntry.md)
 - [FullUsageResult](docs/FullUsageResult.md)
 - [FullUsageRow](docs/FullUsageRow.md)
 - [HashResponse](docs/HashResponse.md)
 - [IAMConnectorCredential](docs/IAMConnectorCredential.md)
 - [InlineResponse200](docs/InlineResponse200.md)
 - [InlineResponse2001](docs/InlineResponse2001.md)
 - [InlineResponse2001Error](docs/InlineResponse2001Error.md)
 - [InlineResponse2002](docs/InlineResponse2002.md)
 - [InlineResponse202](docs/InlineResponse202.md)
 - [InlineResponse500](docs/InlineResponse500.md)
 - [InviteCode](docs/InviteCode.md)
 - [KafkaPlaintextUnauthenticatedConnectionConfiguration](docs/KafkaPlaintextUnauthenticatedConnectionConfiguration.md)
 - [KafkaSaslSslConnectionConfiguration](docs/KafkaSaslSslConnectionConfiguration.md)
 - [Language](docs/Language.md)
 - [License](docs/License.md)
 - [NetworkAccess](docs/NetworkAccess.md)
 - [NewInviteCode](docs/NewInviteCode.md)
 - [OAuthConnectorCredential](docs/OAuthConnectorCredential.md)
 - [Organization](docs/Organization.md)
 - [OrganizationApiKeyCreation](docs/OrganizationApiKeyCreation.md)
 - [OrganizationHostInformation](docs/OrganizationHostInformation.md)
 - [OrganizationMember](docs/OrganizationMember.md)
 - [OrganizationType](docs/OrganizationType.md)
 - [OrganizationTypeListResult](docs/OrganizationTypeListResult.md)
 - [PagedBuildsList](docs/PagedBuildsList.md)
 - [PagedResultList](docs/PagedResultList.md)
 - [PagedResultListObjects](docs/PagedResultListObjects.md)
 - [PagedVersionsList](docs/PagedVersionsList.md)
 - [ProviderInfo](docs/ProviderInfo.md)
 - [RepositoryCommitLog](docs/RepositoryCommitLog.md)
 - [Reservation](docs/Reservation.md)
 - [ReservationCreate](docs/ReservationCreate.md)
 - [ResourceName](docs/ResourceName.md)
 - [SASConnectorCredential](docs/SASConnectorCredential.md)
 - [SCMSSecretToken](docs/SCMSSecretToken.md)
 - [SCMSUserPass](docs/SCMSUserPass.md)
 - [SCMSUserPassOrSecretToken](docs/SCMSUserPassOrSecretToken.md)
 - [ScmBitbucketConfiguration](docs/ScmBitbucketConfiguration.md)
 - [ScmConfiguration](docs/ScmConfiguration.md)
 - [ScmConfigurationRequestDto](docs/ScmConfigurationRequestDto.md)
 - [ScmConfigurationResponseDto](docs/ScmConfigurationResponseDto.md)
 - [ScmConnectionStatus](docs/ScmConnectionStatus.md)
 - [ScmOAuthConfiguration](docs/ScmOAuthConfiguration.md)
 - [ScmUpdateRequest](docs/ScmUpdateRequest.md)
 - [ScmUrls](docs/ScmUrls.md)
 - [ScmUserOAuthStatus](docs/ScmUserOAuthStatus.md)
 - [ScmUserOAuthStatusScmOrganizations](docs/ScmUserOAuthStatusScmOrganizations.md)
 - [SecretProviderRequest](docs/SecretProviderRequest.md)
 - [SecretProviderRequestConfiguration](docs/SecretProviderRequestConfiguration.md)
 - [ServiceAccountConnectorCredential](docs/ServiceAccountConnectorCredential.md)
 - [Settings](docs/Settings.md)
 - [SettingsMandatory](docs/SettingsMandatory.md)
 - [SettingsPublish](docs/SettingsPublish.md)
 - [Source](docs/Source.md)
 - [SourceCreate](docs/SourceCreate.md)
 - [SourceVisibility](docs/SourceVisibility.md)
 - [UpdateRequest](docs/UpdateRequest.md)
 - [User](docs/User.md)
 - [UserUsageResult](docs/UserUsageResult.md)
 - [UserUsageRow](docs/UserUsageRow.md)
 - [UtilityAlgorithm](docs/UtilityAlgorithm.md)
 - [VersionInfo](docs/VersionInfo.md)
 - [VersionInfoPublish](docs/VersionInfoPublish.md)
 - [VersionRequest](docs/VersionRequest.md)
 - [VersionResponse](docs/VersionResponse.md)
 - [VersionType](docs/VersionType.md)


## Documentation For Authorization


## AdminApiKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## ApiKeyAuth

- **Type**: API key
- **API key parameter name**: Authorization
- **Location**: HTTP header


## CookieAuth

- **Type**: API key
- **API key parameter name**: ALGO_SESSION{cookieNameSuffix}
- **Location**: 


## GithubAuth

- **Type**: API key
- **API key parameter name**: X-Hub-Signature
- **Location**: HTTP header


## GithubEventIdentification

- **Type**: API key
- **API key parameter name**: X-GitHub-Event
- **Location**: HTTP header


## XBitbucketKey

- **Type**: API key
- **API key parameter name**: X-Event-Key
- **Location**: HTTP header


## XGitlabEvent

- **Type**: API key
- **API key parameter name**: X-Gitlab-Event
- **Location**: HTTP header


## Author

support@algorithmia.com


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in algorithmia_api_client.apis and algorithmia_api_client.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from algorithmia_api_client.api.default_api import DefaultApi`
- `from algorithmia_api_client.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import algorithmia_api_client
from algorithmia_api_client.apis import *
from algorithmia_api_client.models import *
```

